Scilab2Py is written and maintained by Steven Silvester and
various contributors:

Development Lead
````````````````

- Steven Silvester <steven.silvester@ieee.org>


Patches and Suggestions
```````````````````````

- Stefan van der Walt @stefanv
